<?php
/**
 * Title: Header Hooks
 *
 * Description: Defines actions/hooks for header content.
 *
 * Please do not edit this file. This file is part of the CyberChimps Framework and all modifications
 * should be made in a child theme.
 *
 * @category CyberChimps Framework
 * @package  Framework
 * @since    1.0
 * @author   CyberChimps
 * @license  http://www.opensource.org/licenses/gpl-license.php GPL v3.0 (or later)
 * @link     http://www.cyberchimps.com/
 */

function cyberchimps_header_section_order() {
	//get the defaults from the themes function file and turn the key into the value in a new array to mirror what happens within the theme when their are options saved in the database
	$defaults = array();
	$default  = apply_filters( 'header_drag_and_drop_default', array( 'cyberchimps_header_content' => __( 'Logo + Icons', 'cyberchimps_core' ) ) );
	foreach ( $default as $key => $val ) {
		$defaults[] = $key;
	}
	// call the database results and if they don't exist then call the defaults from above
	$header_section = get_theme_mod( 'header_section_order', $defaults );
	$header_section = ( $header_section == '' ) ? $defaults : $header_section;
	if ( is_array( $header_section ) ) {
		foreach ( $header_section as $func ) { 
			do_action( $func );
		}
	}
}

add_action( 'cyberchimps_header', 'cyberchimps_header_section_order' );

// Logo/Icons header element.
function cyberchimps_logo_icons() {
	?>
	<header id="cc-header" class="row">
		<div class="col-md-7 col-lg-7 col-xs-6">
			<?php if ( function_exists( 'cyberchimps_header_logo' ) ) {
				cyberchimps_header_logo();
			} ?>
		</div>

		<div id="register" class="col-md-5 col-lg-5 col-xs-6">
			<?php if ( function_exists( 'cyberchimps_header_social_icons' ) ) {
				cyberchimps_header_social_icons();
			} ?>
		</div>
	</header>
<?php
}

add_action( 'cyberchimps_header_content', 'cyberchimps_logo_icons' );

// Logo/Search header element.
function cyberchimps_logo_searchform() {
	?>
	<header id="cc-header" class="row">
		<div class="col-lg-7">
			<?php if ( function_exists( 'cyberchimps_header_logo' ) ) {
				cyberchimps_header_logo();
			} ?>
		</div>

		<div id="search" class="col-lg-5">
			<?php
			get_search_form( true );
			?>
		</div>
	</header>
<?php
}

add_action( 'cyberchimps_logo_search', 'cyberchimps_logo_searchform' );

// Description/Icons header element.
function cyberchimps_description_icons() {
	?>
	<header id="cc-header" class="row">
		<div class="col-md-7 col-lg-7">
			<h2 class="site-description"><?php bloginfo( 'description' ); ?></h2>
		</div>

		<div id="register" class="col-md-5 col-lg-5">
			<?php if ( function_exists( 'cyberchimps_header_social_icons' ) ) {
				cyberchimps_header_social_icons();
			} ?>
		</div>
	</header>
<?php
}

add_action( 'cyberchimps_description_icons', 'cyberchimps_description_icons' );

// Logo and Contact
function cyberchimps_sitename_contact() {
	?>
	<header id="cc-header" class="row">
		<div class="col-md-7 col-lg-7">
			<?php if ( function_exists( 'cyberchimps_header_logo' ) ) {
				cyberchimps_header_logo();
			} ?>
		</div>

		<div id="register" class="col-md-5 col-lg-5">
			<?php if ( function_exists( 'cyberchimps_contact_info' ) ) {
				echo cyberchimps_contact_info();
			} ?>
		</div>
	</header>
<?php
}

add_action( 'cyberchimps_sitename_contact', 'cyberchimps_sitename_contact' );

// Logo and Description
function cyberchimps_logo_description() {
	?>
	<header id="cc-header" class="row">
		<div class="col-md-7 col-lg-7">
			<?php if ( function_exists( 'cyberchimps_header_logo' ) ) {
				cyberchimps_header_logo();
			} ?>
		</div>

		<div id="description" class="col-md-5 col-lg-5">
			<?php if ( function_exists( 'cyberchimps_description' ) ) {
				echo cyberchimps_description();
			} ?>
		</div>
	</header>
<?php
}

add_action( 'cyberchimps_logo_description', 'cyberchimps_logo_description' );

// Defines action for header elelment "Logo"
function cyberchimps_logo() {
	?>
	<header id="cc-header" class="row">
		<div class="col-md-7 col-lg-7">
			<?php if ( function_exists( 'cyberchimps_header_logo' ) ) {
				cyberchimps_header_logo();
			} ?>
		</div>
	</header>
<?php
}

add_action( 'cyberchimps_logo', 'cyberchimps_logo' );

// Header left content (sitename or logo)
function cyberchimps_header_logo() {
	$url = ( get_theme_mod( 'custom_logo_url' ) == '1' ) ? get_theme_mod( 'custom_logo_url_link' ) : esc_url( home_url() );
	
	$theme_options_main = get_option('theme_mods_'.get_template());
	if(!isset($theme_options_main['custom_logo']))
	{
		set_theme_mod('custom_logo', 1);
	}
	
	if ( has_custom_logo( $blog_id = 0 )) {
		$custom_logo_id = get_theme_mod( 'custom_logo' );
		$logo = wp_get_attachment_image_src( $custom_logo_id );
		?>
		<div id="logo">
			<a href="<?php echo $url ?>" title="<?php echo get_bloginfo( 'name' ); ?>"><img src="<?php echo $logo[0] ? $logo[0] : apply_filters('cyberchimps_default_logo' , $url); ?>" alt="<?php echo get_bloginfo( 'name' ); ?>"></a>
		</div>
	<?php
	} else {
		if ( function_exists( 'cyberchimps_header_site_title' ) ) {
			cyberchimps_header_site_title();
		}
	}
}

function cyberchimps_header_site_title() {
	?>
	<div class="hgroup">
		<h2 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" title="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h2>
	</div>
<?php
}

/**
 * Social icons positioned in header and some theme's footer
 *
 * The key of the $social variable has to match the font icon you want to use. If that differs from the name you want displayed set the title key
 * e.g. $social['twitterbird']['title'] = 'twitter';
 *
 * styling is located in /lib/css/core.css
 * icon fonts are from http://drinchev.github.io/monosocialiconsfont/
 */
function cyberchimps_header_social_icons() {

	// get the design of the icons to apply the right class
	$design = get_theme_mod( 'theme_backgrounds', 'default' );

	// create array of social icons to loop through to check if they are set and add title key to
	// social networks with names different to key

	$social['twitterbird']['set']   = get_theme_mod( 'social_twitter', 'checked' );
	$social['twitterbird']['title'] = 'twitter';
	$social['twitterbird']['url']   = get_theme_mod( 'twitter_url' );
	$social['facebook']['set']      = get_theme_mod( 'social_facebook', 'checked' );
	$social['facebook']['url']      = get_theme_mod( 'facebook_url' );
	$social['googleplus']['set']    = get_theme_mod( 'social_google', 'checked' );
	$social['googleplus']['url']    = get_theme_mod( 'google_url' );
	$social['flickr']['set']        = get_theme_mod( 'social_flickr' );
	$social['flickr']['url']        = get_theme_mod( 'flickr_url' );
	$social['pinterest']['set']     = get_theme_mod( 'social_pinterest' );
	$social['pinterest']['url']     = get_theme_mod( 'pinterest_url' );
	$social['linkedin']['set']      = get_theme_mod( 'social_linkedin' );
	$social['linkedin']['url']      = get_theme_mod( 'linkedin_url' );
	$social['youtube']['set']       = get_theme_mod( 'social_youtube' );
	$social['youtube']['url']       = get_theme_mod( 'youtube_url' );
	$social['map']['set']           = get_theme_mod( 'social_googlemaps' );
	$social['map']['title']         = 'google maps';
	$social['map']['url']           = get_theme_mod( 'googlemaps_url' );
	$social['email']['set']         = get_theme_mod( 'social_email' );
	$social['email']['url']         = 'mailto:' . get_theme_mod( 'email_url' );
	$social['rss']['set']           = get_theme_mod( 'social_rss' );
	$social['rss']['url']           = get_theme_mod( 'rss_url' );
	$social['instagram']['set']		= get_theme_mod( 'social_instagram' );
	$social['instagram']['url']		= get_theme_mod( 'instagram_url' );

	$output = '';

	// get the blog title to add to link title
	$link_title = get_bloginfo( 'title' );

	// Loop through the $social variable
	foreach ( $social as $key => $value ) {

		// Check that the social icon has been set
		if ( !empty( $value['set'] ) ) {

			// check if title is set and use it otherwise use key as title
			$title = ( isset( $social[$key]['title'] ) ) ? $social[$key]['title'] : $key;

			// Create the output
			$output .= '<a href="' . esc_url( $social[$key]['url'] ) . '"' . ( "email" != $key ? ' target="_blank"' : '' )
				. ' title="' . esc_attr( $link_title . ' ' . ucwords( $title ) ) . '" class="symbol ' . $key . '"></a>';
		}

	}

	// Echo to the page
	?>
	<div id="social">
		<div class="<?php echo $design; ?>-icons">
			<?php echo $output; ?>
		</div>
	</div>

<?php
}

// Custom HTML header element.
function cyberchimps_custom_header_element_content() {
	?>
	<header id="cc-header" class="row">
		<div class="col-md-7 col-lg-7">
			<?php echo stripslashes( get_theme_mod( 'custom_header_element' ) ); ?>
		</div>
	</header>
<?php
}

// Sitename/Register
function cyberchimps_logo_register_content() {
?>
	<header id="cc-header" class="row">
		<div class="col-md-7 col-lg-7">
			<?php if ( function_exists( 'cyberchimps_header_logo' ) ) {
				cyberchimps_header_logo();
			} ?>
		</div>

		<div id="register" class="col-md-5 col-lg-5">
			<div class="register">
				<?php if ( !is_user_logged_in() ) : ?>
					<?php wp_loginout(); ?> <?php wp_meta(); ?> | <?php wp_register( '', '', true ); ?>
				<?php else :
					echo __('Welcome back', 'cyberchimps_core'); ?> <strong><?php
						$current_user = wp_get_current_user();
						echo( $current_user->user_login ); ?></strong> | <?php wp_loginout(); ?>
				<?php endif; ?>
			</div>
		</div>
	</header>
<?php
}

add_action( 'cyberchimps_sitename_register', 'cyberchimps_logo_register_content' );

// Full-Width Logo
function cyberchimps_banner_content() {

	// Getting banner options
	$banner  = get_theme_mod( 'header_banner_image' );
	$default = get_template_directory_uri() . apply_filters( 'cyberchimps_banner_img', '/cyberchimps/lib/images/banner.jpg' );
	$url     = get_theme_mod( 'header_banner_url' );
	?>
	<header id="cc-header" class="row">
		<div id="banner">
			<?php if ( $banner != "" ): ?>
				<a href="<?php echo $url; ?>"><img src="<?php echo $banner; ?>" alt="logo"></a>
			<?php endif; ?>
			<?php if ( $banner == "" ): ?>
				<a href="<?php echo $url; ?>"><img src="<?php echo $default; ?>" alt="logo"></a>
			<?php endif; ?>
		</div>
	</header>
<?php
}

add_action( 'cyberchimps_banner', 'cyberchimps_banner_content' );

//contact info
function cyberchimps_contact_info() {
	$contact = apply_filters( 'cyberchimps_header_contact', get_theme_mod( 'contact_details' ) ); ?>

	<div class="contact_details">
		<?php echo $contact; ?>
	</div>
<?php
}

//description
function cyberchimps_description() {
	$description = get_bloginfo( 'description' );?>
	<div class="blog-description">
		<p><?php echo $description; ?></p>
	</div>
<?php
}

?>
