<?php
/**
 * Custom functions that act independently of the theme templates
 *
 * Eventually, some of the functionality here could be replaced by core features
 *
 * @package Agri Pro
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function agripro_body_classes( $classes ) {
	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	return $classes;
}
add_filter( 'body_class', 'agripro_body_classes' );

if ( version_compare( $GLOBALS['wp_version'], '4.1', '<' ) ) :
	/**
	 * Filters wp_title to print a neat <title> tag based on what is being viewed.
	 *
	 * @param string $title Default title text for current view.
	 * @param string $sep Optional separator.
	 * @return string The filtered title.
	 */
	function agripro_wp_title( $title, $sep ) {
		if ( is_feed() ) {
			return $title;
		}

		global $page, $paged;

		// Add the blog name.
		$title .= get_bloginfo( 'name', 'display' );

		// Add the blog description for the home/front page.
		$site_description = get_bloginfo( 'description', 'display' );
		if ( $site_description && ( is_home() || is_front_page() ) ) {
			$title .= " $sep $site_description";
		}

		// Add a page number if necessary.
		if ( ( $paged >= 2 || $page >= 2 ) && ! is_404() ) {
			$title .= " $sep " . sprintf( esc_html__( 'Page %s', 'agri-lite' ), max( $paged, $page ) );
		}

		return $title;
	}
	add_filter( 'wp_title', 'agripro_wp_title', 10, 2 );

	/**
	 * Title shim for sites older than WordPress 4.1.
	 *
	 * @link https://make.wordpress.org/core/2014/10/29/title-tags-in-4-1/
	 * @todo Remove this function when WordPress 4.3 is released.
	 */
	function agripro_render_title() {
		?>
		<title><?php wp_title( '|', true, 'right' ); ?></title>
		<?php
	}
	add_action( 'wp_head', 'agripro_render_title' );
endif;

function cyberchimps_sp_product_render( $span_class = 'col-lg-3 col-md-3 col-sm-3 col-xs-12'){ 
	global $product; 
	if ( get_option( 'woocommerce_enable_review_rating' ) === 'no' ) {
		$show_rating = false;
	}else{
		$show_rating = true;
	}
	
	?>
	<div class="product_widget_size <?php echo $span_class; ?> products">
		<div class="tumbnails product-image-archive">
                   	<?php echo $product->get_image(array(200,200)); ?>                    
			<?php woocommerce_show_product_sale_flash(); ?>
                         <?php if( function_exists( 'YITH_WCQV' ) ){ 
                             $label = esc_html( get_option( 'yith-wcqv-button-label' ) );
                             ?>
                            <div class="view-product">
                              <a data-product_id="<?php echo $product->id;?>" class="yith-wcqv-button" href="#"><?php echo $label;?></a>
                            </div>
                        <?php } ?> 
		</div>

		<div class="details">
			<a class="sf-product-title" href="<?php echo esc_url( get_permalink( $product->id ) ); ?>" title="<?php echo esc_attr( $product->get_title() ); ?>">
				<span class="product-title"><?php echo $product->get_title(); ?></span>
			</a>
			<?php if ( ! empty( $show_rating ) ) echo $product->get_rating_html(); ?> 
                    <a class="button product_details_btn" href="<?php echo esc_url( get_permalink( $product->id ) ); ?>" title="<?php echo esc_attr( $product->get_title() ); ?>">View Details</a>
		</div>

	</div><?php 

} ?>

                <?php

add_action( 'widgets_init', 'recent_posts_widget' );

function recent_posts_widget() {
	register_widget( 'Agri_Recent_Post_Widget' );
}

/**
 * Recent_Posts widget class
 *
 * @since 2.8.0
 */
class Agri_Recent_Post_Widget extends WP_Widget {
	
	function __construct() {
		$widget_ops = array( 'classname' => 'agri_recent_posts', 'description' => __('A widget that displays recent posts ', 'agri-lite') );
		
		$control_ops = array( 'width' => 300, 'height' => 350, 'id_base' => 'agri_recent_posts' );
		
		parent::__construct( 'agri_recent_posts', __('AgriPro Recent Posts', 'agri-lite'), $widget_ops, $control_ops );
	}

	function widget($args, $instance) {
		$cache = wp_cache_get('widget_recent_posts', 'widget');

		if ( !is_array($cache) )
			$cache = array();

		if ( ! isset( $args['widget_id'] ) )
			$args['widget_id'] = $this->id;

		if ( isset( $cache[ $args['widget_id'] ] ) ) {
			echo $cache[ $args['widget_id'] ];
			return;
		}

		ob_start();
		extract($args);

		$title = apply_filters('widget_title', empty($instance['title']) ? __('Recent Posts', 'agri-lite') : $instance['title'], $instance, $this->id_base);
		if ( empty( $instance['number'] ) || ! $number = absint( $instance['number'] ) )
 			$number = 10;

		$r = new WP_Query( apply_filters( 'widget_posts_args', array( 'posts_per_page' => $number, 'no_found_rows' => true, 'post_status' => 'publish', 'ignore_sticky_posts' => true ) ) );
		if ($r->have_posts()) :
?>
		<?php echo $before_widget; ?>
		<?php if ( $title ) echo $before_title . $title . $after_title;
		// Replaces the excerpt "more" text by a link
		function new_excerpt_more($more) {
		       global $post;
			return '<a class="moretag" href="'. get_permalink($post->ID) . '">...</a>';
		}
		add_filter('excerpt_more', 'new_excerpt_more');
		function custom_excerpt_length( $length ) {
			return 15;
		}
		add_filter( 'excerpt_length', 'custom_excerpt_length', 999 );
?>
		<ul class="agri_recent_posts_ul">
		
			<?php while ( $r->have_posts() ) : $r->the_post(); ?>
			
			<li class="agri_recent_posts_li row">
                            <?php ?>
				<div class="single_product_image col-md-4"><?php the_post_thumbnail(array(150, 150)); ?></div>
				<div class="agri_post_content col-md-8">
					<a class="recent_post_title" href="<?php the_permalink() ?>" title="<?php echo esc_attr( get_the_title() ? get_the_title() : get_the_ID() ); ?>"><?php if ( get_the_title() ) the_title(); else the_ID(); ?></a>
					<div class="row_sidebar">
							<span class="agri_recent_posted_on">
								<?php cyberchimps_posted_on();?>
							</span>
					</div>
				</div>
           		</li>

			<?php endwhile; ?>
		</ul>
		<?php echo $after_widget; ?>
<?php
		// Reset the global $the_post as this query will have stomped on it
		wp_reset_postdata();

		endif;

		$cache[$args['widget_id']] = ob_get_flush();
		wp_cache_set('widget_recent_posts', $cache, 'widget');
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['number'] = (int) $new_instance['number'];
		$this->flush_widget_cache();

		$alloptions = wp_cache_get( 'alloptions', 'options' );
		if ( isset($alloptions['widget_recent_entries']) )
			delete_option('widget_recent_entries');

		return $instance;
	}

	function flush_widget_cache() {
		wp_cache_delete('widget_recent_posts', 'widget');
	}

	function form( $instance ) {
		$title     = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';
		$number    = isset( $instance['number'] ) ? absint( $instance['number'] ) : 5;
?>
		<p><label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', 'agri-lite' ); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo $title; ?>" /></p>

		<p><label for="<?php echo $this->get_field_id( 'number' ); ?>"><?php _e( 'Number of posts to show:', 'agri-lite' ); ?></label>
		<input id="<?php echo $this->get_field_id( 'number' ); ?>" name="<?php echo $this->get_field_name( 'number' ); ?>" type="text" value="<?php echo $number; ?>" size="3" /></p>
<?php
	}
}

?>
